<?php

namespace common\logic\User\User\Service;

use common\helpers\CSV;
use common\helpers\Price;
use common\logic\User\User\Repository\UserRepository;
use common\logic\AbstractGenerator;
use yii\base\ErrorException;

class UsersCreditCsvGenerator extends AbstractGenerator
{
    protected UserSolver $userSolver;
    protected UserRepository $userRepository;

    public function loadDependencies(): void
    {
        $this->userSolver = $this->loadService(UserSolver::class);
        $this->userRepository = $this->loadService(UserRepository::class);
    }

    public function exportUsersCreditAsCsv(string $type)
    {
        if($type == 'negative') {
            $filename = 'Utilisateurs_credit_negatif.csv';
            $usersArray = $this->userRepository->findUsersWithNegativeCredit();
        }
        elseif($type == 'positive') {
            $filename = 'Utilisateurs_credit_positif.csv';
            $usersArray = $this->userRepository->findUsersWithPositiveCredit();
        }
        else {
            throw new ErrorException('Le paramètre $type est invalide.');
        }

        $data = [
            ['Client', 'Email', 'Téléphone', 'Crédit']
        ];
        foreach($usersArray as $user) {
            $data[] = [
                $this->userSolver->getUsernameFromArray($user, true),
                $user['email'],
                $user['phone'],
                CSV::formatPrice($user['credit']),
            ];
        }

        CSV::send($filename, $data);
    }
}