<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use common\logic\Ticket\Ticket\Model\Ticket;
use common\logic\Ticket\Ticket\Model\TicketSearch;
use yii\filters\AccessControl;
use yii\filters\VerbFilter;
use yii\helpers\Html;
use yii\web\NotFoundHttpException;

class SupportController extends BackendController
{
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::class,
                'actions' => [
                ],
            ],
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->getUserManager()->hasAccessBackend();
                        }
                    ]
                ],
            ],
        ];
    }

    public function actionIndex()
    {
        $searchTicket = new TicketSearch();
        $dataProviderTicketOpen = $searchTicket->search('producer', ['TicketSearch' => ['status' => Ticket::STATUS_OPEN]]);
        $dataProviderTicketClosed = $searchTicket->search('producer', ['TicketSearch' => ['status' => Ticket::STATUS_CLOSED]]);

        return $this->render('index', [
            'context' => 'producer',
            'searchTicket' => $searchTicket,
            'dataProviderTicketOpen' => $dataProviderTicketOpen,
            'dataProviderTicketClosed' => $dataProviderTicketClosed
        ]);
    }

    public function actionCreate()
    {
        $userCurrent = $this->getUserCurrent();
        $ticketManager = $this->getTicketManager();
        $ticketMessageManager = $this->getTicketMessageManager();
        $ticket = $ticketManager->instanciateTicket($this->getProducerCurrent(), $userCurrent);

        if ($ticket->load(\Yii::$app->request->post()) && $ticket->validate() && $ticketManager->create($ticket)) {
            $ticketMessageManager->createTicketMessage($ticket, $userCurrent, $ticket->message);
            $this->setFlash('success', 'Le ticket a bien été créé.');
            return $this->redirect(['view', 'id' => $ticket->id]);
        } else {
            return $this->render('@backend/views/support/create', [
                'ticket' => $ticket
            ]);
        }
    }

    public function actionView(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticketMessageManager = $this->getTicketMessageManager();
        $ticket = $this->findTicket($id);
        $ticketManager->viewTicket($ticket, $this->getUserCurrent());
        $ticketMessage = $ticketMessageManager->instanciateTicketMessage($ticket, $this->getUserCurrent());
        if ($ticketMessage->load(\Yii::$app->request->post()) && $ticketManager->createTicketMessage($ticketMessage)) {
            return $this->redirect(['view', 'id' => $ticket->id, '#' => 'bottom']);
        }

        return $this->render('@backend/views/support/view', [
            'ticket' => $ticket,
            'ticketMessageResponse' => $ticketMessage
        ]);
    }

    public function actionClose(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $this->findTicket($id);
        $ticketManager->closeTicket($ticket);
        $this->addFlash('success', "Le ticket <strong>".Html::encode($ticket->subject)."</strong> a bien été fermé.");
        return $this->redirect(['index']);
    }

    public function actionOpen(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $this->findTicket($id);
        $ticketManager->openTicket($ticket);
        $this->addFlash('success', "Le ticket a bien été ouvert.");
        return $this->redirect(['index']);
    }

    public function findTicket(int $id)
    {
        $ticketManager = $this->getTicketManager();
        $ticket = $ticketManager->findOneTicketById($id);

        if ($ticket && $ticketManager->hasTicketAccess($ticket, $this->getUserCurrent())) {
            return $ticket;
        } else {
            throw new NotFoundHttpException("Le ticket est introuvable.");
        }
    }
}
