<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use common\logic\Config\TaxRate\Model\TaxRate;
use Yii;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;
use yii\data\ActiveDataProvider;

/**
 * TaxRateAdminController implements the CRUD actions for TaxRate model.
 */
class TaxRateAdminController extends BackendController
{
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::class,
                'actions' => [
                    'delete' => ['post'],
                ],
            ],
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->isUserCurrentAdmin();
                        }
                    ]
                ],
            ],
        ];
    }

    public function actionIndex()
    {
        $dataProviderTaxRate = new ActiveDataProvider([
            'query' => TaxRate::find()
        ]);

        return $this->render('index', [
            'dataProviderTaxRate' => $dataProviderTaxRate,
        ]);
    }

    public function actionCreate()
    {
        $model = $this->getTaxRateManager()->instanciateTaxRate();

        if ($model->load(\Yii::$app->request->post()) && $model->save()) {
            $this->setFlash('success', 'Taxe créée.');
            return $this->redirect(['index']);
        } else {
            return $this->render('create', [
                'model' => $model,
            ]);
        }
    }

    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(\Yii::$app->request->post()) && $model->save()) {
            $this->setFlash('success', 'Taxe éditée.');
            return $this->redirect(['index']);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    public function actionDelete(int $id)
    {
        $taxRateManager = $this->getTaxRateManager();
        $taxRate = $this->findModel($id);
        $taxRateManager->delete($taxRate);

        $this->setFlash('success', 'Taxe supprimé');

        return $this->redirect(['tax-rate-admin/index']);
    }

    protected function findModel($id)
    {
        $taxRateManager = $this->getTaxRateManager();
        if (($taxRate = $taxRateManager->findOneTaxRateById($id)) !== null) {
            return $taxRate;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

}
