<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use yii\helpers\Html;
use yii\grid\GridView;
use common\helpers\Url;
use common\logic\Document\Invoice\Model\Invoice;
use common\logic\Order\Order\Model\Order;

$producerManager = $this->getProducerManager();
$invoiceManager = $this->getInvoiceManager();
$userManager = $this->getUserManager();

$this->setTitle('Factures');
$this->addBreadcrumb($this->getTitle());
$this->addButton(['label' => 'Nouvelle facture <span class="glyphicon glyphicon-plus"></span>', 'url' => 'invoice/create', 'class' => 'btn btn-primary']);

?>

<div class="invoice-index">

    <?php if (Invoice::searchCount()): ?>
        <?= GridView::widget([
            'filterModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'columns' => [
                [
                    'attribute' => 'status',
                    'label' => 'Statut',
                    'filter' => [
                        'draft' => 'Brouillon',
                        'valid' => 'Valide',
                    ],
                    'format' => 'raw',
                    'value' => function ($invoice) use ($invoiceManager) {
                        return $invoiceManager->getHtmlLabel($invoice);
                    }
                ],
                [
                    'attribute' => 'reference',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($invoice) {
                        return (strlen($invoice->reference) > 0) ? $invoice->reference : '';
                    }
                ],
                'name',
                [
                    'attribute' => 'username',
                    'header' => 'Utilisateur',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($invoice) use ($userManager) {
                        return $userManager->getUsername($invoice->user);
                    }
                ],
                [
                    'attribute' => 'date',
                    'header' => 'Date',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($invoice) {
                        return date('d/m/Y', strtotime($invoice->date));
                    }
                ],
                [
                    'attribute' => 'amount',
                    'header' => 'Montant',
                    'format' => 'raw',
                    'value' => function ($invoice) use ($invoiceManager) {
                        $amountWithTax = $invoiceManager->getAmountWithTax($invoice, Order::INVOICE_AMOUNT_TOTAL);
                        return $invoiceManager->getAmountWithTax($invoice, Order::INVOICE_AMOUNT_TOTAL, true);
                    }
                ],
                [
                    'header' => 'Payée',
                    'format' => 'raw',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($invoice) use ($invoiceManager) {
                        $amountWithTax = $invoiceManager->getAmountWithTax($invoice, Order::INVOICE_AMOUNT_TOTAL);
                        if($amountWithTax && $invoiceManager->isInvoicePaid($invoice)) {
                            return '<span class="label label-success">Oui</span>';
                        }

                        return '<span class="label label-default">Non</span>';
                    }
                ],
                [
                    'attribute' => 'is_sent',
                    'header' => 'Envoyée',
                    'format' => 'raw',
                    'headerOptions' => ['class' => 'column-hide-on-mobile'],
                    'filterOptions' => ['class' => 'column-hide-on-mobile'],
                    'contentOptions' => ['class' => 'column-hide-on-mobile'],
                    'value' => function ($model) {
                        if ($model->is_sent) {
                            return '<span class="label label-success">Oui</span>';
                        } else {
                            return '<span class="label label-default">Non</span>';
                        }
                    }
                ],
                [
                    'class' => 'yii\grid\ActionColumn',
                    'template' => '{validate} {update} {delete} {send} {download} {export-csv-evoliz}',
                    'headerOptions' => ['class' => 'column-actions'],
                    'contentOptions' => ['class' => 'column-actions'],
                    'buttons' => [
                        'validate' => function ($url, $invoice) use ($invoiceManager) {
                            return ($invoiceManager->isStatusDraft($invoice) ? Html::a('<span class="glyphicon glyphicon-ok"></span>', $url, [
                                'title' => 'Valider', 'class' => 'btn btn-default'
                            ]) : '');
                        },
                        'send' => function ($url, $invoice) {
                            return ((isset($invoice->user) && strlen($invoice->user->email) > 0) ? Html::a('<span class="glyphicon glyphicon-send"></span>', $url, [
                                'title' => 'Envoyer', 'class' => 'btn btn-default'
                            ]) : '');
                        },
                        'download' => function ($url, $invoice) {
                            return Html::a('<span class="glyphicon glyphicon-download-alt"></span>', $url, [
                                'title' => 'Télécharger', 'class' => 'btn btn-default'
                            ]);
                        },
                        'export-csv-evoliz' => function ($url, $invoice) use ($producerManager) {
                            if ($producerManager->getConfig('option_export_evoliz')) {
                                return Html::a('<span class="glyphicon glyphicon-save-file"></span> Evoliz', $url, [
                                    'title' => 'Export CSV Evoliz', 'class' => 'btn btn-default'
                                ]);
                            }

                            return '';
                        },
                        'update' => function ($url, $invoice) {
                            return Html::a('<span class="glyphicon glyphicon-pencil"></span>', $url, [
                                'title' => 'Modifier', 'class' => 'btn btn-default'
                            ]);
                        },
                        'delete' => function ($url, $invoice) use ($invoiceManager) {
                            return ($invoiceManager->isStatusDraft($invoice) ? Html::a('<span class="glyphicon glyphicon-trash"></span>', $url, [
                                'title' => 'Supprimer', 'class' => 'btn btn-default'
                            ]) : '');
                        }
                    ],
                ],
            ],
        ]); ?>
    <?php else: ?>
        <div class="alert alert-info">Aucune facture enregistrée</div>
    <?php endif; ?>
</div>
