<?php

/** 
Copyright distrib (2018) 

contact@opendistrib.net

Ce logiciel est un programme informatique servant à aider les producteurs 
à distribuer leur production en circuits courts. 

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant 
donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
*/

use yii\helpers\Html;
use yii\grid\GridView;
use common\logic\User\User\Model\User;
use common\logic\Producer\Producer\Model\Producer;
use common\helpers\Price;

$producerManager = $this->getProducerManager();

$this->setTitle('Producteurs') ;
$this->addBreadcrumb($this->getTitle()) ;
$this->addButton(['label' => 'Nouveau producteur <span class="glyphicon glyphicon-plus"></span>', 'url' => 'producer-admin/create', 'class' => 'btn btn-primary']) ;

?>

<div class="alert alert-info">
        Facturé le mois dernier : <strong><?= $sumPrices ?> €</strong><br />
</div>

<?= GridView::widget([
    'dataProvider' => $dataProviderProducer,
    'columns' => [
        [
            'attribute' => 'active',
            'format' => 'raw',
            'value' => function($model) {
                $html = '' ;
                if($model->active) {
                    $html .= '<span class="label label-success">En ligne</span>' ;
                }
                else {
                    $html .= '<span class="label label-danger">Hors-ligne</span>' ;
                }

                if(strlen($model->code))
                {
                    $html .= ' <span class="glyphicon glyphicon-lock" data-toggle="tooltip" data-placement="bottom" data-original-title="'.Html::encode($model->code).'"></span>' ;
                }

                return $html ;
            }
        ],
        'name',
        /*[
            'attribute' => 'date_creation',
            'format' => 'raw',
            'value' => function($model) {
                return date('d/m/Y', strtotime($model->date_creation)) ;
            }
        ],*/
        /*[
            'attribute' => 'Lieu',
            'format' => 'raw',
            'value' => function($model) {
                return Html::encode($model->city.' ('.$model->postcode.')') ;
            }
        ],*/
        /*[
            'attribute' => 'Utilisateurs',
            'format' => 'raw',
            'value' => function($model) {
                if(!$model->userProducer || !count($model->userProducer))
                {
                    return 'Aucun utilisateur' ;
                }
                else {
                    $users = count($model->userProducer).' client' ;
                    if(count($model->userProducer) > 1) {
                        $users .= 's' ;
                    }
                    return $users ;
                }
                    
            }
        ],*/
        [
            'attribute' => 'Contact',
            'format' => 'raw',
            'value' => function($model) {
                if(!isset($model->user) || (isset($model->user) && count($model->user) == 0)) 
                {
                    return 'Aucun contact' ;
                }
                else {
                    foreach($model->user as $u)
                    {
                        if($u->status ==  User::STATUS_PRODUCER)
                        {
                            return Html::encode($u->lastname.' '.$u->name)
                                .'<br />'.Html::encode($u->email)
                                .'<br />'.Html::encode($u->phone) ;
                        }
                    }
                    
                }
            }
        ],
        /*[
            'attribute' => 'Prix libre',
            'label' => 'Prix libre',
            'format' => 'raw',
            'value' => function($model) {
                if(is_null($model->free_price)) {
                    return '' ;
                }
                else {
                    $str = '';
                    if($model->isBillingTypeFreePrice()) {
                        $str .= '<strong>';
                    }

                    $str .= $model->getFreePrice();

                    if($model->isBillingTypeFreePrice()) {
                        $str .= '</strong>';
                    }

                    return $str;
                }
            }
        ],*/
        [
            'label' => 'Facturation',
            'format' => 'raw',
            'value' => function($producer) use ($producerManager) {

                $str = '';
                $str .= '<ul style="margin: 0px;padding-left: 15px;">';

                $isBillingFrequencyMonthly = $producerManager->isBillingFrequencyMonthly($producer);
                $summaryMonthly = $producerManager->getSummaryAmountsToBeBilled($producer, 'Mois dernier', 1);
                $isBillingFrequencyQuaterly = $producerManager->isBillingFrequencyQuarterly($producer);
                $summaryQuaterly = $producerManager->getSummaryAmountsToBeBilled($producer, '3 derniers mois', 3);
                $isBillingFrequencyBiannual = $producerManager->isBillingFrequencyBiannual($producer);
                $summaryBiannual = $producerManager->getSummaryAmountsToBeBilled($producer, '6 derniers mois', 6);

                if(($isBillingFrequencyMonthly && $summaryMonthly)
                    || ($isBillingFrequencyQuaterly && $summaryQuaterly)
                    || ($isBillingFrequencyBiannual && $summaryBiannual)) {

                    $str .= '<li>';
                    if ($isBillingFrequencyMonthly && $summaryMonthly) {
                        $str .= $summaryMonthly;
                    } elseif ($isBillingFrequencyQuaterly && $summaryQuaterly) {
                        $str .= $summaryQuaterly;
                    } elseif ($isBillingFrequencyBiannual && $summaryBiannual) {
                        $str .= $summaryBiannual;
                    }

                    if ($producer->option_billing_reduction && strlen($str)) {
                        $str .= '<br /><u>Avec réduction</u> : ';
                        if ($producer->option_billing_reduction_percentage) {
                            $str .= ' ' . $producer->option_billing_reduction_percentage . '&nbsp;%';
                        }
                    }
                    $str .= '</li>';

                    $str .= '<li>Facturation '.strtolower(Producer::$billingFrequencyArray[$producer->option_billing_frequency]).'</li>';
                }

                if($producer->option_billing_permanent_transfer) {
                    $str .= '<li>Virement permanent : <strong>'.Price::format($producer->option_billing_permanent_transfer_amount).'</strong></li>';
                }

                $str .= '</ul>';

                return $str;
            }
        ],
        [
            'attribute' => 'admin_comment',
            'label' => 'Commentaire',
            'format' => 'raw',
            'value' => function($producer) {
                if($producer->admin_comment) {
                    return $producer->admin_comment;
                }

                return '';
            }
        ],
        [
            'class' => 'yii\grid\ActionColumn',
            'template' => '{update} {dolibarr} {billing} {alwaysdata}',
            'headerOptions' => ['class' => 'column-actions'],
            'contentOptions' => ['class' => 'column-actions'],
            'buttons' => [
                'update' => function ($url, $model) {
                    return Html::a(
                        '<span class="glyphicon glyphicon-pencil"></span>',
                        $url,
                        [
                            'title' => 'Modifier',
                            'class' => 'btn btn-default'
                        ]
                    );
                },
                'dolibarr' => function ($url, $model) {
                    return Html::a(
                        '<span class="glyphicon glyphicon-paste"></span>',
                        $url,
                        [
                            'title' => 'Générer la facture sur Dolibarr',
                            'class' => 'btn btn-default'
                        ]
                    );
                },
                'billing' => function ($url, $model) {
                    return Html::a(
                        '<span class="glyphicon glyphicon-euro"></span>',
                        $url,
                        [
                            'title' => 'Facturation',
                            'class' => 'btn btn-default'
                        ]
                    );
                },
                'alwaysdata' => function ($url, $model) {
                    return Html::a(
                        '<span class="glyphicon glyphicon-road"></span>',
                        $url,
                        [
                            'title' => 'Redirections Alwaysdata (email et url courte)',
                            'class' => 'btn btn-default'
                        ]
                    );
                },
            ],
        ],
    ],
]); ?>