<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\logic\User\User\Wrapper\UserManager;
use yii\helpers\Html;
use common\helpers\Price;
use yii\grid\GridView;
use common\logic\Product\Product\Wrapper\ProductManager;

$productManager = ProductManager::getInstance();
$userManager = UserManager::getInstance();

$this->setTitle('Liste des prix (' . Html::encode($model->name) . ')');
$this->addBreadcrumb(['label' => 'Produits', 'url' => ['index']]);
$this->addBreadcrumb(['label' => $model->name, 'url' => ['update', 'id' => $model->id]]);
$this->addBreadcrumb('Modifier');

?>

<?=
$this->render('../_nav', [
    'model' => $model,
    'action' => $action,
]);
?>

<div class="col-md-12">

    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">
                Prix spécifiques à ce produit
                <a href="<?= Yii::$app->urlManager->createUrl(['product/prices-create', 'idProduct' => $model->id]) ?>"
                   class="btn btn-default btn-xs">
                    Nouveau prix
                    <span class="glyphicon glyphicon-plus"></span>
                </a>
            </h3>
        </div>
        <div class="panel-body">
            <?php

            echo GridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'attribute' => 'id_user',
                        'format' => 'raw',
                        'value' => function ($model) use ($userManager) {
                            if ($model->user) {
                                return $userManager->getUsername($model->user);
                            }
                            return '<span class="label label-success">Tous</span>';
                        }
                    ],
                    [
                        'attribute' => 'id_user_group',
                        'format' => 'raw',
                        'value' => function ($model) {
                            if ($model->userGroup) {
                                return $model->userGroup->name;
                            }
                            return '<span class="label label-success">Tous</span>';
                        }
                    ],
                    [
                        'attribute' => 'id_point_sale',
                        'format' => 'raw',
                        'value' => function ($model) {
                            if ($model->pointSale) {
                                return $model->pointSale->name;
                            }
                            return '<span class="label label-success">Tous</span>';
                        }
                    ],
                    [
                        'attribute' => 'from_quantity',
                        'value' => function ($productPrice) use ($productManager) {
                            if ($productPrice->from_quantity) {
                                return $productPrice->from_quantity . ' ' . $productManager->strUnit($productManager->getRefUnit($productPrice->product->unit), 'wording');
                            }

                            return '';
                        }
                    ],
                    [
                        'attribute' => 'price',
                        'value' => function ($productPrice) {
                            return Price::numberTwoDecimals($productPrice->price) . ' €';
                        }
                    ],
                    [
                        'attribute' => 'price',
                        'header' => 'Prix (TTC)',
                        'value' => function ($productPrice) use ($model) {
                            return Price::numberTwoDecimals(Price::getPriceWithTax($productPrice->price, $model->taxRate->value)) . ' €';
                        }
                    ],
                    [
                        'class' => 'yii\grid\ActionColumn',
                        'template' => '{update} {delete}',
                        'headerOptions' => ['class' => 'column-actions'],
                        'contentOptions' => ['class' => 'column-actions'],
                        'buttons' => [
                            'update' => function ($url, $model) {
                                return Html::a('<span class="glyphicon glyphicon-pencil"></span>', ['product/prices-update', 'id' => $model->id], [
                                    'title' => 'Modifier', 'class' => 'btn btn-default'
                                ]);
                            },
                            'delete' => function ($url, $model) {
                                return Html::a('<span class="glyphicon glyphicon-trash"></span>', ['product/prices-delete', 'id' => $model->id], [
                                    'title' => 'Supprimer', 'class' => 'btn btn-default'
                                ]);
                            }
                        ],
                    ],
                ],
            ]);

            ?>
        </div>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">Rappel du prix de base</h3>
        </div>
        <div class="panel-body">
            <p>Prix de base : <strong><?= Price::format($productManager->getPrice($model)); ?> HT</strong> /
                <strong><?= Price::format($productManager->getPriceWithTax($model)); ?> TTC</strong><br/></p>
        </div>
    </div>
</div>