<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\logic\Order\ProductOrder\Model;

use common\helpers\GlobalParam;
use common\components\ActiveRecordCommon;
use common\logic\Config\TaxRate\Model\TaxRate;
use common\logic\Order\Order\Model\Order;
use common\logic\Product\Product\Model\Product;

/**
 * This is the model class for table "product_order".
 */
class ProductOrder extends ActiveRecordCommon
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'product_order';
    }

    /*
     * Relations
     */

    public function getProduct()
    {
        return $this->hasOne(Product::class, ['id' => 'id_product']);
    }

    public function populateProduct(Product $product)
    {
        $this->populateFieldObject('id_product', 'product', $product);
    }

    public function getOrder()
    {
        return $this->hasOne(Order::class, ['id' => 'id_order']);
    }

    public function populateOrder(Order $order)
    {
        $this->populateFieldObject('id_order', 'order', $order);
    }

    public function getTaxRate()
    {
        return $this->hasOne(TaxRate::class, ['id' => 'id_tax_rate']);
    }

    public function populateTaxRate(TaxRate $taxRate)
    {
        $this->populateFieldObject('id_tax_rate', 'taxRate', $taxRate);
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_order', 'id_product', 'quantity'], 'required'],
            [['id_order', 'id_product', 'id_tax_rate'], 'integer'],
            [['unit'], 'string', 'max' => 255],
            [['quantity'], 'number', 'min' => 0],
            [['price', 'invoice_price'], 'double'],
            [['description'], 'safe']
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'id_order' => 'Commande',
            'id_product' => 'Product',
            'quantity' => 'Quantité',
            'unit' => 'Unité',
            'id_tax_rate' => 'Taxe',
            'description' => 'Description',
            'price' => 'Prix',
            'invoice_price' => 'Prix facturé',
        ];
    }

    public function afterFind()
    {
        if(!$this->id_tax_rate) {
            $this->populateRelation('taxRate', GlobalParam::getCurrentProducer()->taxRate);
        }

        parent::afterFind();
    }

    public function getPrice()
    {
        return $this->price;
    }

    public function getInvoicePrice()
    {
        return $this->invoice_price;
    }
}