<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\logic\Product\Product\Model;

use common\helpers\GlobalParam;
use common\logic\Config\TaxRate\Model\TaxRate;
use common\logic\Distribution\ProductDistribution\Model\ProductDistribution;
use common\logic\Producer\Producer\Model\Producer;
use common\logic\Product\Product\Service\ProductSolver;
use common\logic\Product\ProductCategory\Model\ProductCategory;
use common\logic\Product\ProductPointSale\Model\ProductPointSale;
use common\logic\Product\ProductPrice\Model\ProductPrice;
use common\components\ActiveRecordCommon;
use common\logic\StatusInterface;
use common\logic\Subscription\ProductSubscription\Model\ProductSubscription;
use yii\web\UploadedFile;

/**
 * This is the model class for table "product".
 *
 */
class Product extends ActiveRecordCommon implements StatusInterface
{
    public $total = 0;
    public $apply_distributions = true;
    public $price_with_tax = 0;
    public $wording_unit = '';
    public $pointsSale;

    /**
     * @var UploadedFile
     */
    public $photoFile;

    public static $unitsArray = [
        'piece' => [
            'unit' => 'piece',
            'wording_unit' => 'la pièce',
            'wording' => 'pièce(s)',
            'wording_short' => 'p.',
            'coefficient' => 1
        ],
        'g' => [
            'ref_unit' => 'kg',
            'unit' => 'g',
            'wording_unit' => 'le g',
            'wording' => 'g',
            'wording_short' => 'g',
            'coefficient' => 1000
        ],
        'kg' => [
            'unit' => 'kg',
            'wording_unit' => 'le kg',
            'wording' => 'kg',
            'wording_short' => 'kg',
            'coefficient' => 1
        ],
        'mL' => [
            'ref_unit' => 'L',
            'unit' => 'mL',
            'wording_unit' => 'le mL',
            'wording' => 'mL',
            'wording_short' => 'mL',
            'coefficient' => 1000
        ],
        'L' => [
            'unit' => 'L',
            'wording_unit' => 'le litre',
            'wording' => 'L',
            'wording_short' => 'L',
            'coefficient' => 1
        ],
    ];

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'product';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name', 'id_producer'], 'required'],
            [['order', 'id_producer', 'id_tax_rate', 'id_product_category', 'status'], 'integer'],
            [['monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday', 'unavailable', 'apply_distributions', 'available_on_points_sale'], 'boolean'],
            [['price', 'weight', 'step', 'quantity_max', 'quantity_max_monday', 'quantity_max_tuesday', 'quantity_max_wednesday', 'quantity_max_thursday', 'quantity_max_friday', 'quantity_max_saturday', 'quantity_max_sunday'], 'number'],
            [['photoFile'], 'file', 'extensions' => 'png, jpg, jpeg', 'mimeTypes' => 'image/png, image/jpeg'],
            [['name', 'reference', 'description', 'photo', 'unit'], 'string', 'max' => 255],
            [['recipe'], 'string', 'max' => 1000],
            ['step', 'required', 'message' => 'Champs obligatoire', 'when' => function ($model) {
                if ($model->unit != 'piece') {
                    return true;
                }
                return false;
            }],
            [['price_with_tax', 'wording_unit', 'pointsSale'], 'safe']
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'name' => 'Nom',
            'reference' => 'Référence',
            'description' => 'Description',
            'photoFile' => 'Photo',
            'price' => 'Prix (€) TTC',
            'weight' => 'Poids',
            'recipe' => 'Recette',
            'monday' => 'Lundi',
            'tuesday' => 'Mardi',
            'wednesday' => 'Mercredi',
            'thursday' => 'Jeudi',
            'friday' => 'Vendredi',
            'saturday' => 'Samedi',
            'sunday' => 'Dimanche',
            'order' => 'Ordre',
            'quantity_max' => 'Quantité max par défaut',
            'quantity_max_monday' => 'Quantité max : lundi',
            'quantity_max_tuesday' => 'Quantité max : mardi',
            'quantity_max_wednesday' => 'Quantité max : mercredi',
            'quantity_max_thursday' => 'Quantité max : jeudi',
            'quantity_max_friday' => 'Quantité max : vendredi',
            'quantity_max_saturday' => 'Quantité max : samedi',
            'quantity_max_sunday' => 'Quantité max : dimanche',
            'unavailable' => 'Épuisé',
            'apply_distributions' => 'Appliquer ces modifications dans les distributions futures',
            'unit' => 'Unité',
            'step' => 'Pas',
            'id_tax_rate' => 'TVA',
            'id_product_category' => 'Catégorie',
            'available_on_points_sale' => 'Par défaut',
            'status' => 'Actif',
        ];
    }

    public function afterFind()
    {
        if ($this->taxRate == null) {
            if(GlobalParam::getCurrentProducerId() && $this->id_producer == GlobalParam::getCurrentProducerId()) {
                $producer = GlobalParam::getCurrentProducer();
            }
            else {
                $producer = Producer::searchOne(['id' => $this->id_producer]);
            }

            if ($producer) {
                $this->populateRelation('taxRate', $producer->taxRate);
            }
        }

        parent::afterFind();

        $productSolver = ProductSolver::getInstance();
        $this->wording_unit = $productSolver->strUnit($this->unit);
        $this->price_with_tax = $productSolver->getPriceWithTax($this);
    }

    public function getProductDistribution()
    {
        return $this->hasMany(ProductDistribution::class, ['id_product' => 'id']);
    }

    public function getProductSubscription()
    {
        return $this->hasMany(ProductSubscription::class, ['id_product' => 'id']);
    }

    public function getTaxRate()
    {
        return $this->hasOne(TaxRate::class, ['id' => 'id_tax_rate']);
    }

    public function populateTaxRate(TaxRate $taxRate): void
    {
        $this->populateFieldObject('id_tax_rate', 'taxRate', $taxRate);
    }

    public function getProductPrice()
    {
        return $this->hasMany( ProductPrice::class, ['id_product' => 'id']);
    }

    public function getProductCategory()
    {
        return $this->hasOne( ProductCategory::class, ['id' => 'id_product_category']);
    }

    public function populateProductCategory(ProductCategory $productCategory): void
    {
        $this->populateFieldObject('id_product_category', 'productCategory', $productCategory);
    }

    public function getProductPointSale()
    {
        return $this->hasMany(ProductPointSale::class, ['id_product' => 'id']);
    }

    /**
     * Enregistre le produit.
     */
    public function save($runValidation = true, $attributeNames = NULL)
    {
        $this->id_producer = GlobalParam::getCurrentProducerId();
        return parent::save($runValidation, $attributeNames);
    }
}
