<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\logic\User\UserProducer\Model;

use common\logic\Producer\Producer\Model\Producer;
use common\logic\User\User\Model\User;
use Yii;
use common\components\ActiveRecordCommon;

/**
 * This is the model class for table "user_producer".
 */
class UserProducer extends ActiveRecordCommon
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'user_producer';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_user', 'id_producer'], 'required'],
            [['id_user', 'id_producer', 'product_price_percent'], 'integer'],
            [['active', 'bookmark', 'credit_active', 'newsletter'], 'boolean'],
            [['credit', 'product_price_percent'], 'double'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_user' => 'Utilisateur',
            'id_producer' => 'Producteur',
            'active' => 'Actif',
            'bookmark' => 'Favoris',
            'credit_active' => 'Crédit',
            'product_price_percent' => 'Prix produits : pourcentage'
        ];
    }

    public function getProducer()
    {
        return $this->hasOne(Producer::class, ['id' => 'id_producer']);
    }

    public function populateProducer(Producer $producer): void
    {
        $this->populateFieldObject('id_producer', 'producer', $producer);
    }

    public function getUser()
    {
        return $this->hasOne(User::class, ['id' => 'id_user']);
    }

    public function populateUser(User $user): void
    {
        $this->populateFieldObject('id_user', 'user', $user);
    }

    public function getIdUser(): int
    {
        return $this->id_user;
    }

    public function setIdUser(int $idUser): self
    {
        $this->id_user = $idUser;

        return $this;
    }

    public function getIdProducer(): int
    {
        return $this->id_producer;
    }

    public function setIdProducer(int $idProducer): self
    {
        $this->id_producer = $idProducer;

        return $this;
    }

    public function getActive(): ?bool
    {
        return $this->active;
    }

    public function setActive(bool $active): self
    {
        $this->active = $active;

        return $this;
    }

    public function getBookmark(): ?bool
    {
        return $this->bookmark;
    }

    public function setBookmark(bool $bookmark): self
    {
        $this->bookmark = $bookmark;

        return $this;
    }

    public function setNewsletter(bool $newsletter): self
    {
        $this->newsletter = $newsletter;

        return $this;
    }

    public function getCredit(): float
    {
        return $this->credit;
    }

    public function setCredit(float $credit): self
    {
        $this->credit = $credit;

        return $this;
    }

    public function getCreditActive(): ?bool
    {
        return $this->credit_active;
    }

    public function setCreditActive(bool $creditActive): self
    {
        $this->credit_active = $creditActive;

        return $this;
    }

    public function getProductPricePercent(): float
    {
        return $this->product_price_percent;
    }

    public function setProductPricePercent(float $productPricePercent): self
    {
        $this->product_price_percent = $productPricePercent;

        return $this;
    }
}
