<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\logic\User\User\Wrapper\UserManager;
use yii\helpers\Html;
use yii\bootstrap\Nav;
use common\logic\Producer\Producer\Model\Producer;

\common\assets\CommonAsset::register($this);
\frontend\assets\AppAsset::register($this);

$userManager = UserManager::getInstance();
$isHome = (Yii::$app->controller->id == 'site' && \Yii::$app->controller->action->id == 'index');
$producer = null;
if ($userManager->isCurrentProducer()) {
    $producer = Producer::searchOne(['id' => \Yii::$app->user->identity->id_producer]);
}

?>
<?php $this->beginPage() ?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <title><?php if ($isHome): ?>Opendistrib | <?= Html::encode($this->title) ?><?php else: ?><?= Html::encode($this->title) ?> | Opendistrib<?php endif; ?></title>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="baseurl" content="<?= Yii::$app->urlManagerFrontend->baseUrl; ?>">
    <meta name="baseurl-absolute"
          content="<?= Yii::$app->urlManagerFrontend->getHostInfo() . Yii::$app->urlManagerBackend->baseUrl; ?>">
    <?= Html::csrfMetaTags() ?>
    <link rel="icon" type="image/png" href="<?= $this->getUrlManager()->getBaseUrl(); ?>/img/favicon-distrib.png">
    <!--[if IE]><link rel="shortcut icon" type="image/x-icon" href="<?= \Yii::$app->urlManager->getBaseUrl(); ?>/img/favicon.ico"><![endif]-->
    <?php $this->head() ?>
    <!--[if lt IE 9]>
    <script src="<?= $this->getUrlManager()->getBaseUrl(); ?>/js/html5shiv.min.js"></script>
    <link href="<?= $this->getUrlManager()->getBaseUrl(); ?>/css/ie.css" rel="stylesheet">
    <![endif]-->
    <!--[if IE 7]>
            <link href="<?= $this->getUrlManager()->getBaseUrl(); ?>/css/ie7.css" rel="stylesheet">
    <![endif]-->
    <?= $this->render('@common/views/matomo.php') ?>
</head>
<body class="<?php if ($isHome): echo 'home'; endif; ?><?php if (!Yii::$app->user->isGuest): ?> connected<?php endif; ?>">
<?php $this->beginBody() ?>

<?= $this->render('@common/views/nav_user_top', [
    'context' => 'frontend'
]); ?>

<header id="header">
    <nav class="navbar navbar-default">
        <div id="the-header" class="container">
            <div class="navbar-header">
                <a id="link-home" class="" href="<?= $this->getUrlManager()->createUrl('site/index'); ?>">
                    Opendistrib
                    <!--<img src="<?= $this->getUrlManager()->baseUrl ?>/img/souke.png" alt="Souke" />-->
                    <!--<span style="position: relative;top: 22px;left: 5px;font-family: 'capsuularegular'">-alpha.fr</span>-->
                </a>
                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#w0-collapse"><span
                            class="sr-only">Toggle navigation</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
            </div>
            <div id="w0-collapse" class="collapse navbar-collapse">
                <?php
                echo Nav::widget([
                    'encodeLabels' => false,
                    'options' => ['class' => 'nav nav-pills navbar-nav navbar-right'],
                    'items' => [
                        [
                            'label' => '<span class="glyphicon glyphicon-home"></span> Accueil',
                            'url' => $this->getUrlManager()->createUrl(['site/index']),
                            'active' => $this->getControllerAction() == 'site/index',
                            'options' => ['id' => 'li-home']
                        ],
                        [
                            'label' => '<span class="glyphicon glyphicon-grain"></span> Producteurs',
                            'url' => $this->getUrlManager()->createUrl(['site/producers']),
                            'active' => $this->getControllerAction() == 'site/producers',
                            'options' => ['id' => 'li-producteurs']
                        ],
                        [
                            'label' => '<span class="glyphicon glyphicon-info-sign"></span> À propos',
                            'url' => $this->getUrlManager()->createUrl(['site/about']),
                            'active' => $this->getControllerAction() == 'site/about',
                            'options' => ['id' => 'li-about']
                        ],
                        [
                            'label' => '<span class="glyphicon glyphicon-envelope"></span> Contact',
                            'url' => $this->getUrlManager()->createUrl(['site/contact']),
                            'active' => $this->getControllerAction() == 'site/contact',
                            'options' => ['id' => 'li-contact']
                        ],
                    ]
                ]);
                ?>
            </div>
        </div>
    </nav>
</header>

<div id="main">
    <section id="header-title">
        <div class="container">
            <h1>
                <?php if ($isHome): ?>
                    <span class="glyphicon glyphicon-tasks"></span>
                    Opendistrib, un outil pour organiser des ventes en circuit court
                <?php else: ?>
                    <span class="glyphicon glyphicon-<?= $this->getIcon(); ?>"></span>
                    <?= $this->getTitle(); ?>
                <?php endif; ?>
            </h1>
        </div>
    </section>

    <section class="container" id="content">
        <?php if (Yii::$app->session->hasFlash('error')): ?>
            <div class="alert alert-danger" role="alert">
                <?= \Yii::$app->session->getFlash('error') ?>
            </div>
        <?php endif; ?>
        <?php if (Yii::$app->session->hasFlash('success')): ?>
            <div class="alert alert-success" role="alert">
                <?= \Yii::$app->session->getFlash('success') ?>
            </div>
        <?php endif; ?>

        <?= $content ?>
    </section>
</div>
<footer id="footer">
    <div class="container">
        <a href="<?php echo $this->getUrlManager()->createUrl('site/service'); ?>">Fonctionnalités, services & tarifs</a> <span class="bull">&bull;</span>
        <a href="<?php echo $this->getUrlManager()->createUrl('site/opinion'); ?>">Avis & suggestions</a> <span class="bull">&bull;</span>
        <a href="<?php echo $this->getUrlManager()->createUrl('site/mentions'); ?>">Mentions légales</a> <span class="bull">&bull;</span>
        <a href="<?php echo $this->getUrlManager()->createUrl('site/cgv'); ?>">Conditions générales de service</a> <span class="bull">&bull;</span>
        <a href="<?php echo $this->getUrlManager()->createUrl('site/source-code'); ?>">Code source</a>
    </div>
</footer>

<?php $this->endBody() ?>
</body>
</html>
<?php $this->endPage() ?>
