<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace producer\controllers;

use common\helpers\GlobalParam;
use common\helpers\MeanPayment;
use common\logic\Payment\Model\Payment;
use producer\models\CreditForm;
use yii\data\ActiveDataProvider;
use yii\filters\VerbFilter;

class CreditController extends ProducerBaseController
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'stripe-verification' => ['post'],
                ],
            ]
        ];
    }

    public function actions()
    {
        return [
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    public function beforeAction($action)
    {
        $this->enableCsrfValidation = false;
        return parent::beforeAction($action);
    }

    /**
     * Affiche l'historique du crédit client.
     */
    public function actionHistory(string $returnPayment = '')
    {
        if (\Yii::$app->user->isGuest) {
            return $this->redirect($this->getUrlManagerFrontend()->createAbsoluteUrl(['site/producer', 'id' => $producer->id]));
        }

        $userContainer = $this->getUserContainer();
        $paymentContainer = $this->getPaymentContainer();
        $userCurrent = $this->getUserCurrent();

        if (strlen($returnPayment)) {
            if ($returnPayment == 'success') {
                $this->setFlash('success', "Paiement accepté : votre compte vient d'être crédité.");
            }
            if ($returnPayment == 'cancel') {
                $this->setFlash('error', 'Paiement annulé.');
            }
        }

        return $this->render('history', [
            'dataProvider' => $paymentContainer->getRepository()
                ->queryPaymentsCreditHistoryByUser($userCurrent)->getDataProvider(20),
            'creditUser' => $userContainer->getRepository()->getCredit($userCurrent)
        ]);
    }

    public function actionAdd()
    {
        $producer = $this->getProducerCurrent();
        if (\Yii::$app->user->isGuest) {
            return $this->redirect($this->getUrlManagerFrontend()->createAbsoluteUrl(['site/producer', 'id' => $producer->id]));
        }

        if ($producer->online_payment || $producer->option_stripe_mode_test) {

            $creditForm = new CreditForm;

            if ($creditForm->load(\Yii::$app->request->post()) && $creditForm->validate()) {
                $user = GlobalParam::getCurrentUser();

                \Stripe\Stripe::setApiKey(
                    $this->getProducerManager()->getPrivateKeyApiStripe($producer)
                );

                $checkout_session = \Stripe\Checkout\Session::create([
                    'line_items' => [
                        [
                            'price_data' => [
                                'currency' => 'eur',
                                'product_data' => [
                                    'name' => 'Alimentation crédit',
                                ],
                                'unit_amount' => (float) $creditForm->amount * 100,
                            ],
                            'quantity' => 1,
                        ]
                    ],
                    'payment_method_types' => ['card'],
                    'mode' => 'payment',
                    'customer_email' => $user->email,
                    'client_reference_id' => $user->id,
                    'payment_intent_data' => [
                        'metadata' => [
                            'user_id' => $user->id,
                            'producer_id' => $producer->id
                        ],
                    ],
                    'success_url' => $this->getUrlManagerProducer()->createAbsoluteUrl(
                        [
                            'credit/history',
                            'returnPayment' => 'success'
                        ]
                    ),
                    'cancel_url' => $this->getUrlManagerProducer()->createAbsoluteUrl(
                        [
                            'credit/history',
                            'returnPayment' => 'cancel'
                        ]
                    ),
                ]);

                header("HTTP/1.1 303 See Other");
                header("Location: " . $checkout_session->url);
                die();
            }

            return $this->render('add', [
                'creditForm' => $creditForm
            ]);
        } else {
            throw new \yii\base\UserException('Cette option est désactivée chez ce producteur.');
        }
    }

    public function actionStripeVerification()
    {
        $orderManager = $this->getOrderManager();
        $paymentManager = $this->getPaymentManager();
        $producerManager = $this->getProducerManager();
        $userManager = $this->getUserManager();
        $producer = $this->getProducerCurrent();
        $contactProducer = $producerManager->getMainContact($producer);

        $payload = @file_get_contents('php://input');
        $sig_header = $_SERVER['HTTP_STRIPE_SIGNATURE'];

        try {
            $event = \Stripe\Webhook::constructEvent(
                $payload,
                $sig_header,
                $producerManager->getPrivateKeyEndpointStripe($producer)
            );
        } catch (\UnexpectedValueException $e) {
            // Invalid payload
            http_response_code(400);
            exit();
        } catch (\Stripe\Exception\SignatureVerificationException $e) {
            // Invalid signature
            http_response_code(400);
            exit();
        }

        $paymentIntent = $event->data->object;
        $paymentIntentMetadata = $paymentIntent->metadata;
        $amount = $paymentIntent->amount / 100;
        $idUser = $paymentIntentMetadata->user_id;

        if($idUser) {
            $user = $userManager->findOneUserById($idUser);

            if (isset($paymentIntentMetadata->order_id)) {
                $order = $this->getOrderManager()->findOneOrderById($paymentIntentMetadata->order_id);
                $orderManager->initOrder($order);
                $pointSale = $this->getPointSaleManager()->findOnePointSaleById($order->id_point_sale);
                $distribution = $this->getDistributionManager()->findOneDistributionById($order->id_distribution);
            }

            // Handle the event
            switch ($event->type) {
                case 'charge.succeeded':

                    $paymentExist = Payment::searchOne([
                        'id_user' => $idUser,
                        'amount' => $amount,
                    ], [
                        'conditions' => [
                            'date > DATE_SUB(NOW(), INTERVAL 1 MINUTE)'
                        ]
                    ]);

                    if (!$paymentExist) {

                        $paymentManager->creditUser($user, $amount, MeanPayment::CREDIT_CARD, $user);

                        if (isset($order) && $order) {

                            $paymentManager->payOrder($order, MeanPayment::CREDIT_CARD, $user, true);


                            // client : envoi d'un email de confirmation de paiement
                            /*\Yii::$app->mailerService->sendFromProducer(
                                'Confirmation de commande',
                                'paymentOrderConfirm',
                                [
                                    'amount' => $amount,
                                    'user' => $user,
                                    'producer' => $producer,
                                ],
                                $user->email,
                                $producer
                            );*/

                            // producteur : mail de confirmation
                            \Yii::$app->mailerService->sendFromSite(
                                'Confirmation de commande',
                                'orderConfirmProducer',
                                [
                                    'order' => $order,
                                    'pointSale' => $pointSale,
                                    'distribution' => $distribution,
                                    'user' => $user,
                                    'producer' => $producer
                                ],
                                $contactProducer->email
                            );
                        } else {
                            $userProducer = $this->getUserProducerManager()->findOneUserProducer($user);

                            \Yii::$app->mailerService->sendFromProducer(
                                'Alimentation de votre crédit',
                                'creditConfirm',
                                [
                                    'user' => $user,
                                    'userProducer' => $userProducer,
                                    'producer' => $producer,
                                    'amount' => $amount,
                                ],
                                $user->email,
                                $producer
                            );
                        }
                    }

                    break;

                case 'charge.failed':

                    // client
                    \Yii::$app->mailerService->sendFromProducer(
                        'Erreur de paiement',
                        'paymentError',
                        [
                            'amount' => $amount,
                            'user' => $user,
                            'producer' => $producer,
                        ],
                        $user->email,
                        $producer
                    );

                    // producteur
                    if (isset($order) && $order) {
                        \Yii::$app->mailerService->sendFromSite(
                            'Erreur de paiement',
                            'paymentErrorProducer',
                            [
                                'amount' => $amount,
                                'user' => $user,
                                'producer' => $producer,
                                'order' => $order,
                                'distribution' => $distribution
                            ],
                            $contactProducer->email,
                        );
                    }

                    break;

                // handle other event types
                default:
                    echo 'Received unknown event type ' . $event->type;
            }

            http_response_code(200);
        }
        else {
            http_response_code(200);
        }

        die();
    }
}